@@ -45,6 +45,14 @@ while True:
 		
 		conn.storbinary("STOR %s" % file,f)
 		
+	elif cmd.split(" ")[0] == "download":
+		try: file = cmd.split(" ")[1]
+		except: print "argument is not found.";continue;
+		
+		f = open(file,"w")
+		conn.retrbinary("RETR %s"%file,f.write)
+		print "Completed."
+		
 	elif cmd.split(" ")[0] == "cd":
 		try: dir = cmd.split(" ")[1]
 		except: print "argument is not found.";continue;
